==> haskell-js-flot-0.8.3-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-js-flot.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 js-flot
version:              0.8.3
visibility:           public
id:                   js-flot-0.8.3-CzHXKBaovyL8SpvVY5AoqF
key:                  js-flot-0.8.3-CzHXKBaovyL8SpvVY5AoqF
license:              MIT
copyright:            Neil Mitchell 2014
maintainer:           Neil Mitchell <ndmitchell@gmail.com>
author:               Neil Mitchell <ndmitchell@gmail.com>
homepage:             https://github.com/ndmitchell/js-flot#readme
synopsis:             Obtain minified flot code
description:
    This package bundles the minified <http://www.flotcharts.org/ Flot> code
    (a jQuery plotting library) into a Haskell package,
    so it can be depended upon by Cabal packages. The first three components of
    the version number match the upstream flot version. The package is designed
    to meet the redistribution requirements of downstream users (e.g. Debian).

category:             Javascript
abi:                  41930e4953b78498d2853a5ec2fe7194
exposed:              True
exposed-modules:      Language.Javascript.Flot
hidden-modules:       Paths_js_flot
import-dirs:          /usr/lib/ghc-9.2.8/site-local/js-flot-0.8.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/js-flot-0.8.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-js-flot
hs-libraries:         HSjs-flot-0.8.3-CzHXKBaovyL8SpvVY5AoqF
depends:              base-4.16.4.0
haddock-interfaces:   /usr/share/doc/haskell-js-flot/html/js-flot.haddock
haddock-html:         /usr/share/doc/haskell-js-flot/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-js-flot-0.8.3-26-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-js-flot.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 js-flot
version:              0.8.3
visibility:           public
id:                   js-flot-0.8.3-IKtJvuN3TOl6yoqyRfRs9e
key:                  js-flot-0.8.3-IKtJvuN3TOl6yoqyRfRs9e
license:              MIT
copyright:            Neil Mitchell 2014
maintainer:           Neil Mitchell <ndmitchell@gmail.com>
author:               Neil Mitchell <ndmitchell@gmail.com>
homepage:             https://github.com/ndmitchell/js-flot#readme
synopsis:             Obtain minified flot code
description:
    This package bundles the minified <http://www.flotcharts.org/ Flot> code
    (a jQuery plotting library) into a Haskell package,
    so it can be depended upon by Cabal packages. The first three components of
    the version number match the upstream flot version. The package is designed
    to meet the redistribution requirements of downstream users (e.g. Debian).

category:             Javascript
abi:                  a627a1f8f77dadfe1ecf6b3fc8494241
exposed:              True
exposed-modules:      Language.Javascript.Flot
hidden-modules:       Paths_js_flot
import-dirs:          /usr/lib/ghc-9.4.8/site-local/js-flot-0.8.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/js-flot-0.8.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/js-flot-0.8.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-js-flot
hs-libraries:         HSjs-flot-0.8.3-IKtJvuN3TOl6yoqyRfRs9e
depends:              base-4.17.2.1
haddock-interfaces:   /usr/share/doc/haskell-js-flot/html/js-flot.haddock
haddock-html:         /usr/share/doc/haskell-js-flot/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
